==> qtjambi-test-debuginfo-macos-5.15.17.jar: sources/QtJambiTest/QSignalSpy_shell.h <==
#ifndef QSIGNALSPY_SHELL_H
#define QSIGNALSPY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtTest/qsignalspy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QSignalSpy_shell : public QSignalSpy, public QtJambiShellInterface
{
public:
    QSignalSpy_shell(const QObject* obj0, const QMetaMethod& signal1);
    QSignalSpy_shell(const QObject* obj0, const char* aSignal1);
    ~QSignalSpy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSignalSpy_access : public QSignalSpy
{
    jobject __qt_list(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSIGNALSPY_SHELL_H

==> qtjambi-test-debuginfo-macos-6.5.6.jar: sources/QtJambiTest/QSignalSpy_shell.h <==
#ifndef QSIGNALSPY_SHELL_H
#define QSIGNALSPY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtTest/qsignalspy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QSignalSpy_shell : public QSignalSpy, public QtJambiShellInterface
{
public:
    QSignalSpy_shell(const QObject* obj0, const QMetaMethod& signal1);
    QSignalSpy_shell(const QObject* obj0, const char* aSignal1);
    ~QSignalSpy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSignalSpy_access : public QSignalSpy
{
    jobject __qt_list(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSIGNALSPY_SHELL_H
